@@ -51,7 +51,9 @@ public:
 
     void reindexAll();
     void reindexCollection(const qlonglong id);
+    void reindexCollections(const QList<qlonglong> &ids);
     qlonglong indexedItems(const qlonglong id);
+    int numberOfCollectionQueued();
 
     void itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
     void itemChanged(const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers) Q_DECL_OVERRIDE;
@@ -72,6 +74,7 @@ public:
     // Remove the entire db
     void cleanup() Q_DECL_OVERRIDE;
 
+
 private Q_SLOTS:
     void onAbortRequested();
     void onOnlineChanged(bool online);
